@@ -14,12 +14,28 @@
 pub mod nanoevery {
   use crate::hal::atmega4809::hardware::Hardware;
   use crate::hal::atmega4809;
+  use crate::hal::generic::port::PinIdentity;
+
+  /**
+   * Arduino-style pin identifier, used to identify a pin event source at
+   * runtime
+   */
+  pub enum ArduinoPinIdentity {
+    /// The so-called 'analogue' pins (that is, pins that can be attached to
+    /// a timer's PWM output)
+    PinA(u8),
+    /// The 'digital' pins
+    PinD(u8)
+  }
 
   pub struct Arduino {
-
+    #[cfg(feature="tcb0")]
     pub timer0: &'static mut atmega4809::timer::tcb0::TimerImpl,
+    #[cfg(feature="tcb1")]
     pub timer1: &'static mut atmega4809::timer::tcb1::TimerImpl,
+    #[cfg(feature="tcb2")]
     pub timer2: &'static mut atmega4809::timer::tcb2::TimerImpl,
+    #[cfg(feature="tcb3")]
     pub timer3: &'static mut atmega4809::timer::tcb3::TimerImpl,
 
     pub a0: &'static mut atmega4809::port::portd::PinImpl,
@@ -48,8 +64,11 @@ pub mod nanoevery {
 
     pub watchdog: &'static mut atmega4809::watchdog::WatchdogImpl,
 
+    #[cfg(feature="usart3")]
     pub usb_serial: &'static mut atmega4809::serial::usart3::SerialImpl,
+    #[cfg(feature="usart3")]
     pub usb_serial_tx: &'static mut atmega4809::port::portb::PinImpl,
+    #[cfg(feature="usart3")]
     pub usb_serial_rx: &'static mut atmega4809::port::portb::PinImpl,
   }
 
@@ -57,9 +76,13 @@ pub mod nanoevery {
   impl From<&'static mut crate::hal::atmega4809::hardware::Hardware> for Arduino {
     fn from(avr: &'static mut Hardware) -> Self {
       Arduino {
+        #[cfg(feature="tcb0")]
         timer0: avr.timerb0,
+        #[cfg(feature="tcb1")]
         timer1: avr.timerb1,
+        #[cfg(feature="tcb2")]
         timer2: avr.timerb2,
+        #[cfg(feature="tcb3")]
         timer3: avr.timerb3,
 
         a0: atmega4809::port::portd::pin_instance(3),
@@ -87,11 +110,50 @@ pub mod nanoevery {
 
         watchdog: avr.watchdog,
 
+        #[cfg(feature="usart3")]
         usb_serial: avr.usart3.mux(atmega4809::serial::usart3::SerialPortPins::PortB54),
+        #[cfg(feature="usart3")]
         usb_serial_tx: atmega4809::port::portb::pin_instance(4),
+        #[cfg(feature="usart3")]
         usb_serial_rx: atmega4809::port::portb::pin_instance(5),
       }
     }
   }
+
+  impl From<PinIdentity> for ArduinoPinIdentity {
+    fn from(id: PinIdentity) -> Self {
+      match id {
+        PinIdentity::PortA(0) => ArduinoPinIdentity::PinD(2),
+        PinIdentity::PortA(1) => ArduinoPinIdentity::PinD(7),
+        PinIdentity::PortA(2) => ArduinoPinIdentity::PinA(4),
+        PinIdentity::PortA(3) => ArduinoPinIdentity::PinA(5),
+
+        PinIdentity::PortB(0) => ArduinoPinIdentity::PinD(9),
+        PinIdentity::PortB(1) => ArduinoPinIdentity::PinD(10),
+        PinIdentity::PortB(2) => ArduinoPinIdentity::PinD(5),
+
+        PinIdentity::PortC(4) => ArduinoPinIdentity::PinD(0),
+        PinIdentity::PortC(5) => ArduinoPinIdentity::PinD(1),
+        PinIdentity::PortC(6) => ArduinoPinIdentity::PinD(4),
+
+        PinIdentity::PortD(0) => ArduinoPinIdentity::PinA(3),
+        PinIdentity::PortD(1) => ArduinoPinIdentity::PinA(2),
+        PinIdentity::PortD(2) => ArduinoPinIdentity::PinA(1),
+        PinIdentity::PortD(3) => ArduinoPinIdentity::PinA(0),
+        PinIdentity::PortD(4) => ArduinoPinIdentity::PinA(6),
+        PinIdentity::PortD(5) => ArduinoPinIdentity::PinA(7),
+
+        PinIdentity::PortE(3) => ArduinoPinIdentity::PinD(8),
+        PinIdentity::PortE(0) => ArduinoPinIdentity::PinD(11),
+        PinIdentity::PortE(1) => ArduinoPinIdentity::PinD(12),
+        PinIdentity::PortE(2) => ArduinoPinIdentity::PinD(13),
+
+        PinIdentity::PortF(5) => ArduinoPinIdentity::PinD(3),
+        PinIdentity::PortF(4) => ArduinoPinIdentity::PinD(6),
+
+        _ => panic!()
+      }
+    }
+  }
 }
 // Tests =====================================================================
