@@ -12,27 +12,35 @@ use crate::hal::concurrency;
 use crate::hal::concurrency::thread;
 use crate::deviceconsts::clock;
 use crate::hal::generic::cpu::ClockControl;
+#[cfg(feature="alloc_ftr")]
+use crate::alloc;
 
 // Declarations ==============================================================
 extern {
-  #[cfg(feature="atmega4809")]
-  fn oxide_main() -> u8;
+  fn __oxide_main() -> u8;
 }
 
 // Code ======================================================================
 #[no_mangle]
-fn _oxide_boot() -> () {
+fn _oxide_boot() {
   unsafe {
+    // If we have a global allocator, initialise it
+    #[cfg(feature="alloc_ftr")]
+    alloc::initialise();
+
+    // Inititalise the threading/concurrency system
     concurrency::internal::initialise();
 
+    // Set up any hardware-specific configuration
     #[cfg(feature="atmega4809")]
     crate::hal::atmega4809::cpu::clock().clk_per_prescaler(clock::MASTER_CLOCK_PRESCALER);
 
+    // Spawn the main thread
     let _jh = thread::spawn_threadunsafe(||{
-      #[cfg(feature="atmega4809")]
-      oxide_main()
+      __oxide_main()
     });
 
+    // Enter the scheduler loop
     concurrency::internal::run_scheduler();
   }
 }
