@@ -5,12 +5,11 @@
  */
 
 // Imports ===================================================================
-use crate::hal::generic::timer::TimerControl;
+use crate::hal::generic::timer::{TimerControl, TimerIdentity};
 use crate::hal::generic::timer::TimerMode::Periodic;
 use crate::event::{EventSink, OxideEvent};
 
 use crate::deviceconsts::clock::{ MASTER_CLOCK_PRESCALER, MASTER_CLOCK_HZ, MASTER_TICK_FREQ_HZ };
-use static_assertions::const_assert;
 use core::marker::PhantomData;
 
 // Declarations ==============================================================
@@ -36,7 +35,6 @@ where
 
   pub fn using_timer<const FREQ_HZ: u16>(timer: &'static mut T) -> Self {
     const CYCLES_PER_TICK: u16       = (MASTER_CLOCK_HZ as u32/(2u32 * MASTER_CLOCK_PRESCALER as u32 * MASTER_TICK_FREQ_HZ as u32)) as u16; // We use CLK_PER/2 in timer config, hence the 2* term
-    const_assert!(CYCLES_PER_TICK > 10); // Sanity check really
 
     debug_assert!(FREQ_HZ < MASTER_TICK_FREQ_HZ);
     debug_assert!(FREQ_HZ > 0);
@@ -48,8 +46,8 @@ where
   }
 
   pub fn run(&mut self) {
-    self.timer.start(Some(|ticks:u16| {
-      S::event(OxideEvent::MasterClockEvent(ticks));
+    self.timer.start(Some(|source: TimerIdentity, ticks:u16| {
+      S::event(OxideEvent::MasterClockEvent(source, ticks));
       true
     }));
   }
