@@ -9,6 +9,9 @@
 use crate::private::ringq::{RingQ, Coalesce, QueueError};
 use crate::devices::button::ButtonState;
 use crate::devices::serialport::SerialState;
+use crate::hal::generic::timer::TimerIdentity;
+use crate::hal::generic::port::PinIdentity;
+use crate::hal::generic::serial::SerialPortIdentity;
 
 // Declarations ==============================================================
 pub type OxideEventQueue = RingQ<OxideEvent,16>;
@@ -16,31 +19,38 @@ pub type OxideEventQueue = RingQ<OxideEvent,16>;
 /**
  * Events that can cause your application to wake up and need to do something.
  */
-#[derive(Clone)]
+#[derive(Clone,Copy)]
 pub enum OxideEvent {
+  /**
+   * Sent when the system starts up to allow the application to process any
+   * initialisation tasks it needs.  This is guaranteed to be the first
+   * event received by the application program.
+   */
+  Initialise,
+
   /**
    * Sent when the master clock timer tick interrupt occurs.  The number
    * of elapsed clock ticks is included.
    */
-  MasterClockEvent(u16),
+  MasterClockEvent(TimerIdentity, u16),
 
   /**
    * Sent when a button event occurs.  The state of the button when the
    * event was generated is included.
    */
-  ButtonEvent(ButtonState),
+  ButtonEvent(PinIdentity, ButtonState),
 
   /**
    * Sent when a serial port event occurs.
    */
-  SerialEvent(SerialState)
+  SerialEvent(SerialPortIdentity, SerialState)
 }
 
 /**
  * An event sink is something that devices can call to dump their events into.
  */
 pub trait EventSink {
-  fn event(event: OxideEvent) -> ();
+  fn event(event: OxideEvent);
 }
 
 /**
@@ -55,10 +65,10 @@ impl Coalesce for OxideEvent {
   fn coalesce(&mut self, with: &Self) -> Result<(), QueueError> {
     match self {
       // MasterClockEvents we coalesce by adding the ticks together
-      OxideEvent::MasterClockEvent(myticks) => {
+      OxideEvent::MasterClockEvent(source1, myticks) => {
         match with {
-          OxideEvent::MasterClockEvent(ticks) => {
-            if (u16::MAX - *myticks) > *ticks {
+          OxideEvent::MasterClockEvent(source2, ticks) => {
+            if (source1 == source2) && (u16::MAX - *myticks) > *ticks {
               *myticks += ticks;
               Ok(())
             } else {
@@ -69,10 +79,10 @@ impl Coalesce for OxideEvent {
         }
       },
       // Serial events we coalesce by just discarding duplicates
-      OxideEvent::SerialEvent(state) => {
+      OxideEvent::SerialEvent(source1, state) => {
         match with {
-          OxideEvent::SerialEvent(with_state) => {
-            if state == with_state {
+          OxideEvent::SerialEvent(source2, with_state) => {
+            if (source1 == source2) && (state == with_state) {
               Ok(())
             } else {
               Err(QueueError::CannotCoalesce)
@@ -90,7 +100,7 @@ impl Coalesce for OxideEvent {
  * Do-nothing implementation of EventSink.
  */
 impl EventSink for EventDevNull {
-  fn event(_event: OxideEvent) -> () {
+  fn event(_event: OxideEvent) {
   }
 }
 
@@ -102,15 +112,18 @@ mod tests {
   use crate::event::OxideEvent::MasterClockEvent;
   use crate::devices::serialport::SerialState;
   use crate::devices::button::ButtonState;
+  use crate::hal::generic::timer::TimerIdentity;
+  use crate::hal::generic::serial::SerialPortIdentity;
+  use crate::hal::generic::port::PinIdentity;
 
   #[test]
   fn test_event_coalesce_masterclockevent() {
-    let mut event1 = OxideEvent::MasterClockEvent(12);
-    let event2 = OxideEvent::MasterClockEvent(14);
+    let mut event1 = OxideEvent::MasterClockEvent(TimerIdentity::Tcb0, 12);
+    let event2 = OxideEvent::MasterClockEvent(TimerIdentity::Tcb0, 14);
 
-    event1.coalesce(&event2).unwrap();
+    event1.coalesce(&event2);
 
-    if let MasterClockEvent(ticks) = event1 {
+    if let MasterClockEvent(TimerIdentity::Tcb0, ticks) = event1 {
       println!("Coalesced MasterClockEvent (ticks == {})", ticks);
       assert_eq!(ticks, 26);
     }
@@ -118,33 +131,39 @@ mod tests {
 
   #[test]
   fn test_event_coalesce_serialevent_ok() {
-    let mut event1 = OxideEvent::SerialEvent(SerialState::ReadAvailable);
-    let event2 = OxideEvent::SerialEvent(SerialState::ReadAvailable);
+    let mut event1 = OxideEvent::SerialEvent(SerialPortIdentity::Usart0, SerialState::ReadAvailable);
+    let event2 = OxideEvent::SerialEvent(SerialPortIdentity::Usart0, SerialState::ReadAvailable);
 
-    event1.coalesce(&event2).unwrap();
+    event1.coalesce(&event2);
 
-    let mut event1 = OxideEvent::SerialEvent(SerialState::BreakDetected);
-    let event2 = OxideEvent::SerialEvent(SerialState::BreakDetected);
+    let mut event1 = OxideEvent::SerialEvent(SerialPortIdentity::Usart0, SerialState::BreakDetected);
+    let event2 = OxideEvent::SerialEvent(SerialPortIdentity::Usart0, SerialState::BreakDetected);
 
-    event1.coalesce(&event2).unwrap();
+    event1.coalesce(&event2);
   }
 
   #[test]
   #[should_panic]
   fn test_event_coalesce_serialevent_fail() {
-    let mut event1 = OxideEvent::SerialEvent(SerialState::ReadAvailable);
-    let event2 = OxideEvent::SerialEvent(SerialState::BreakDetected);
+    let mut event1 = OxideEvent::SerialEvent(SerialPortIdentity::Usart0, SerialState::ReadAvailable);
+    let event2 = OxideEvent::SerialEvent(SerialPortIdentity::Usart0, SerialState::BreakDetected);
 
-    event1.coalesce(&event2).unwrap();
+    if let Ok(_) = event1.coalesce(&event2) {
+    } else {
+      panic!();
+    }
   }
 
 
   #[test]
   #[should_panic]
   fn test_event_coalesce_fail() {
-    let mut event1 = OxideEvent::MasterClockEvent(42);
-    let event2 = OxideEvent::ButtonEvent(ButtonState::Pressed);
+    let mut event1 = OxideEvent::MasterClockEvent(TimerIdentity::Tcb0, 42);
+    let event2 = OxideEvent::ButtonEvent(PinIdentity::PortA(0),ButtonState::Pressed);
 
-    event1.coalesce(&event2).unwrap();
+    if let Ok(_) = event1.coalesce(&event2) {
+    } else {
+      panic!();
+    }
   }
 }
\ No newline at end of file
