@@ -4,6 +4,7 @@
  * Copyright (c) All Rights Reserved, Tim Walls
  */
 //! ATmega4809 implementations of the generic device traits
+#![allow(unused)]
 use crate::hal::generic::debugled::DebugLed;
 use crate::hal::generic::serial::SerialNoInterruptTx;
 
@@ -23,12 +24,12 @@ use crate::stdout;
 
 #[cfg(feature="panic_handler")]
 #[panic_handler]
-//#[cfg(target_arch="avr")]
+#[cfg(target_arch="avr")]
 fn panic(info: &core::panic::PanicInfo) -> ! {
   unsafe {
     crate::hal::concurrency::interrupt::disable_interrupts();
 
-    #[cfg(any(feature="stdout_usart0",feature="stdout_usart1",feature="stdout_usart2",feature="stdout_usart3"))]
+    #[cfg(feature="stdout")]
     {
       let serial = stdout!();
 
