@@ -15,31 +15,30 @@
 pub mod porta {
   use crate::{atmel_port_tpl};
 
-  atmel_port_tpl!(super::super::ADDR_PORTA, _ivr_porta_port);
+  atmel_port_tpl!(super::super::ADDR_PORTA, crate::hal::generic::port::PinIdentity::PortA, _ivr_porta_port);
 }
 pub mod portb {
   use crate::{atmel_port_tpl};
 
-  atmel_port_tpl!(super::super::ADDR_PORTB, _ivr_portb_port);
+  atmel_port_tpl!(super::super::ADDR_PORTB, crate::hal::generic::port::PinIdentity::PortB, _ivr_portb_port);
 }
 pub mod portc {
   use crate::{atmel_port_tpl};
 
-  atmel_port_tpl!(super::super::ADDR_PORTC, _ivr_portc_port);
+  atmel_port_tpl!(super::super::ADDR_PORTC, crate::hal::generic::port::PinIdentity::PortC, _ivr_portc_port);
 }
 pub mod portd {
   use crate::{atmel_port_tpl};
 
-  atmel_port_tpl!(super::super::ADDR_PORTD, _ivr_portd_port);
+  atmel_port_tpl!(super::super::ADDR_PORTD, crate::hal::generic::port::PinIdentity::PortD, _ivr_portd_port);
 }
 pub mod porte {
   use crate::{atmel_port_tpl};
 
-  atmel_port_tpl!(super::super::ADDR_PORTE, _ivr_porte_port);
+  atmel_port_tpl!(super::super::ADDR_PORTE, crate::hal::generic::port::PinIdentity::PortE, _ivr_porte_port);
 }
-
 pub mod portf {
   use crate::{atmel_port_tpl};
 
-  atmel_port_tpl!(super::super::ADDR_PORTF, _ivr_portf_port);
+  atmel_port_tpl!(super::super::ADDR_PORTF, crate::hal::generic::port::PinIdentity::PortF, _ivr_portf_port);
 }
\ No newline at end of file
