@@ -13,27 +13,28 @@
 
 
 // Code ======================================================================
+#[cfg(feature="tcb0")]
 pub mod tcb0 {
   use crate::atmel_tcb;
 
-  atmel_tcb!(super::super::ADDR_TCB0, _ivr_tcb0_int);
+  atmel_tcb!(super::super::ADDR_TCB0, crate::hal::generic::timer::TimerIdentity::Tcb0, _ivr_tcb0_int);
 }
-
+#[cfg(feature="tcb1")]
 pub mod tcb1 {
   use crate::atmel_tcb;
-  atmel_tcb!(super::super::ADDR_TCB1, _ivr_tcb1_int);
+  atmel_tcb!(super::super::ADDR_TCB1, crate::hal::generic::timer::TimerIdentity::Tcb1, _ivr_tcb1_int);
 }
-
+#[cfg(feature="tcb2")]
 pub mod tcb2 {
   use crate::atmel_tcb;
 
-  atmel_tcb!(super::super::ADDR_TCB2, _ivr_tcb2_int);
+  atmel_tcb!(super::super::ADDR_TCB2, crate::hal::generic::timer::TimerIdentity::Tcb2, _ivr_tcb2_int);
 }
-
+#[cfg(feature="tcb3")]
 pub mod tcb3 {
   use crate::atmel_tcb;
 
-  atmel_tcb!(super::super::ADDR_TCB3, _ivr_tcb3_int);
+  atmel_tcb!(super::super::ADDR_TCB3, crate::hal::generic::timer::TimerIdentity::Tcb3, _ivr_tcb3_int);
 }
 
 
