@@ -43,7 +43,8 @@ pub(in crate) fn busy_loop(c: u16) {
 #[lang = "eh_personality"]
 #[no_mangle]
 #[cfg(target_arch="avr")]
-pub unsafe extern "C" fn rust_eh_personality() -> () {
+#[allow(clippy::missing_safety_doc)]
+pub unsafe extern "C" fn rust_eh_personality() {
 }
 
 #[macro_export]
