@@ -40,6 +40,25 @@ pub enum InterruptMode {
   LowLevel
 }
 
+/**
+ * Identifies a particular pin as the source of an event at runtime.
+ */
+#[derive(Clone,Copy,PartialEq,Eq)]
+pub enum PinIdentity {
+  /// Port A, pin number (u8)
+  PortA(u8),
+  /// Port A, pin number (u8)
+  PortB(u8),
+  /// Port A, pin number (u8)
+  PortC(u8),
+  /// Port A, pin number (u8)
+  PortD(u8),
+  /// Port A, pin number (u8)
+  PortE(u8),
+  /// Port A, pin number (u8)
+  PortF(u8)
+}
+
 /**
  * Callback called by a pin when it generates an interrupt.  The callback
  * is given the new state read from the pin (true = high).
@@ -51,7 +70,7 @@ pub enum InterruptMode {
  * using mutual exclusion where necessary, and *DO NOT DO HEAVY PROCESSING
  * IN THE CALLBACK*.
  */
-pub type PinInterruptHandler = fn(bool) -> ();
+pub type PinInterruptHandler = fn(PinIdentity,bool) -> ();
 
 pub trait Pin {
   /// Set the input/output mode for this pin
@@ -245,16 +264,14 @@ pub mod base {
         core::ptr::write_volatile(&mut self.intflags as *mut u8, 0xff);
       }
     }
-
-
   }
 
   #[macro_export]
   macro_rules! atmel_port_tpl {
-    ($ref:expr, $isr:ident) => {
+    ($ref:expr, $portsrc:expr, $isr:ident) => {
 
 
-      use crate::hal::generic::port::{PinMode,Pin,InterruptMode,PinInterruptHandler};
+      use crate::hal::generic::port::{PinMode,Pin,PinIdentity,InterruptMode,PinInterruptHandler};
       use crate::hal::generic::port::base::{AtmelPortControl,AvrPortRegisterBlock};
 
       pub type PortImpl = AvrPortRegisterBlock;
@@ -265,7 +282,7 @@ pub mod base {
        * interrupt callbacks.
        */
       #[inline(never)]
-      fn nop_handler(_state: bool) -> () {
+      fn nop_handler(_src: PinIdentity, _state: bool) -> () {
         unsafe { llvm_asm!("nop" :::: "volatile" ) }
       }
 
@@ -381,7 +398,7 @@ pub mod base {
        * Return a single pin instance wrapper.
        */
       pub fn pin_instance(pin: u8) -> &'static mut AtmelPin {
-        debug_assert!(pin < 8);
+        //debug_assert!(pin < 8);
 
         unsafe {
           PINS[0].handler = nop_handler;
@@ -403,7 +420,7 @@ pub mod base {
 
           for pin in 0..=7 {
             if (intflags & mask) > 0 {
-              (PINS[pin].handler)((state & mask) > 0);
+              (PINS[pin].handler)($portsrc(pin as u8), (state & mask) > 0);
             }
             mask <<= 1;
           }
@@ -521,10 +538,10 @@ pub mod base {
 
   #[macro_export]
   macro_rules! atmel_port_tpl {
-    ($ref:expr, $isr:ident) => {
+    ($ref:expr, $portsrc:expr, $isr:ident) => {
 
 
-      use crate::hal::generic::port::{PinMode,Pin,InterruptMode,PinInterruptHandler};
+      use crate::hal::generic::port::{PinMode,Pin,PinIdentity,InterruptMode,PinInterruptHandler};
       use crate::hal::generic::port::base::{AtmelPortControl,DummyPortRegisterBlock};
 
       pub type PortImpl = DummyPortRegisterBlock;
@@ -544,7 +561,7 @@ pub mod base {
        * A no-op function that is the default handler for the button
             * interrupt callbacks.
        */
-      fn nop_handler(_state: bool) -> () {
+      fn nop_handler(_src: PinIdentity, _state: bool) -> () {
       }
 
       /**
@@ -655,7 +672,7 @@ pub mod base {
        * Return a single pin instance wrapper.
        */
       pub fn pin_instance(pin: u8) -> &'static mut AtmelPin {
-        debug_assert!(pin < 8);
+        //debug_assert!(pin < 8);
 
         unsafe {
           PINS[0].handler = nop_handler;
