@@ -13,6 +13,23 @@ pub enum TimerMode {
   Periodic
 }
 
+
+/**
+ * Identifies a particular source of timer events, i.e. a particular hardware
+ * clock source, at runtime.
+ */
+#[derive(Clone,Copy,PartialEq,Eq)]
+pub enum TimerIdentity {
+  /// Timer-Counter Type B, 0
+  Tcb0,
+  /// Timer-Counter Type B, 1
+  Tcb1,
+  /// Timer-Counter Type B, 2
+  Tcb2,
+  /// Timer-Counter Type B, 3
+  Tcb3
+}
+
 /**
  * Callback called by a timer when it generates an interrupt.  The callback
  * is given the number of ticks counted since the last such event.  The
@@ -24,7 +41,7 @@ pub enum TimerMode {
  * using mutual exclusion where necessary, and *DO NOT DO HEAVY PROCESSING
  * IN THE CALLBACK*.
  */
-pub type TimerInterruptHandler = fn(u16) ->bool;
+pub type TimerInterruptHandler = fn(TimerIdentity, u16) ->bool;
 
 pub trait TimerControl {
   /// Builder method that sets the number of underlying timer events that
@@ -60,7 +77,7 @@ pub trait TimerControl {
 // Code ======================================================================
 #[cfg(target_arch="avr")]
 pub mod base {
-  use crate::hal::generic::timer::{TimerInterruptHandler, TimerMode, TimerControl};
+  use crate::hal::generic::timer::{TimerInterruptHandler, TimerMode, TimerControl, TimerIdentity};
 
   #[repr(C)]
   pub struct AvrTypeBTimerControl {
@@ -182,7 +199,7 @@ pub mod base {
       match self.mode {
         TimerMode::Periodic => {
           self.tcb.set_periodic_mode();
-          self.tcb.set_top(self.count_max.clone());
+          self.tcb.set_top(self.count_max);
         }
       };
 
@@ -217,10 +234,10 @@ pub mod base {
       T: AtmelTCB
   {
     #[inline(always)]
-    pub(crate) fn call_interrupt(&mut self, ticks: u16) {
+    pub(crate) fn call_interrupt(&mut self, source: TimerIdentity, ticks: u16) {
       match self.interrupt_handler {
         Some(handler) => {
-          match handler(ticks) {
+          match handler(source, ticks) {
             true => {},
             false => self.tcb.disable()
           }
@@ -239,7 +256,7 @@ pub mod base {
 
   #[macro_export]
   macro_rules! atmel_tcb {
-    ($tcbref:expr, $isr:ident) => {
+    ($tcbref:expr, $timersrc:expr, $isr:ident) => {
       use crate::hal::generic::timer::TimerMode;
       use crate::hal::generic::timer::base::{ AtmelTimer, AtmelTCB, AvrTypeBTimerControl };
 
@@ -272,7 +289,7 @@ pub mod base {
             Some(atmeltimer) => {
 
               if counter == 0 {
-                atmeltimer.call_interrupt(COUNT_INTS.clone());
+                atmeltimer.call_interrupt($timersrc, COUNT_INTS.clone());
                 core::ptr::write_volatile(&mut COUNT_INTS as *mut u16, atmeltimer.interrupt_period())
               } else {
                 core::ptr::write_volatile(&mut COUNT_INTS as *mut u16, counter-1);
@@ -289,7 +306,7 @@ pub mod base {
 
 #[cfg(not(target_arch="avr"))]
 pub mod base {
-  use crate::hal::generic::timer::{TimerInterruptHandler, TimerMode, TimerControl};
+  use crate::hal::generic::timer::{TimerInterruptHandler, TimerMode, TimerControl, TimerIdentity};
 
   #[repr(C)]
   pub struct DummyTypeBTimerControl {
@@ -409,10 +426,10 @@ pub mod base {
       T: DummyTCB
   {
     #[allow(dead_code)]
-    pub(crate) fn call_interrupt(&mut self, ticks: u16) {
+    pub(crate) fn call_interrupt(&mut self, source: TimerIdentity, ticks: u16) {
       match self.interrupt_handler {
         Some(handler) => {
-          match handler(ticks) {
+          match handler(source, ticks) {
             true => {},
             false => self.tcb.disable()
           }
@@ -429,7 +446,7 @@ pub mod base {
 
   #[macro_export]
   macro_rules! atmel_tcb {
-    ($tcbref:expr, $isr:ident) => {
+    ($tcbref:expr, $timersrc:expr, $isr:ident) => {
       use crate::hal::generic::timer::TimerMode;
       use crate::hal::generic::timer::base::{ DummyTimer, DummyTypeBTimerControl };
 
